// -*-Mode: C++;-*-

#ifndef __helpers_h
#define __helpers_h

#include <string>
#include <vector>

//for duplicate files
int copy_file(const char*source, const char*target,bool lock_it = false);
int move_file(const char*source, const char*target,bool lock_it = false);

int get_dir_files(const std::string&directory,std::vector<std::string>&target,bool check_lock = false);
int is_locked(const std::string&directory,const std::string&file_name);
int select_file(const std::string & aFile);
#endif
